@@ -1,5 +1,6 @@
 import requests
 class getAdministrativeDivisions:
+    message = ""
     def getDivisionsForLetter(self):
         url = "https://wft-geo-db.p.rapidapi.com/v1/geo/adminDivisions"
 
@@ -13,4 +14,8 @@ class getAdministrativeDivisions:
         response = requests.request("GET", url, headers=headers, params=querystring)
         city = response.json()
         print([i['name'] for i in city['data']])
-
+        global message
+        message = [i['name'] for i in city['data']]
+    def getMessage(self):
+        global message
+        return message
