@@ -1,5 +1,6 @@
 import requests
 
+from myPackage.libPackage2.getCountries import getCountries
 from myPackage.libPackage2.getCountriesByName import getCountriesByName
 
 
@@ -21,8 +22,9 @@ class getCities:
         global message
         return message
 def main():
-    countries = getCountriesByName("r")
-    countries.getCitiesByLetter()
-    print(countries.getMessage())
+    countries = getCountries()
+    message=""
+    countries.getCountries(message)
+    print(countries.getCountries(message))
 if __name__ == '__main__':
     main();
\ No newline at end of file
