@@ -3,7 +3,8 @@ import time
 import requests
 class getCountries:
     message = ""
-    def getCountries(self):
+    def getCountries(self,message):
+        result = ""
         for x in range(19):
             offset=x*10
             url = "https://wft-geo-db.p.rapidapi.com/v1/geo/countries"
@@ -19,9 +20,9 @@ class getCountries:
             countries = response.json()
             time.sleep(1.5)
             print([i['name'] for i in countries['data']])
-            global message
-            message = [i['name'] for i in countries['data']] + message
-            i=0;
+            message = [i['name'] for i in countries['data']]
+            result = result,message
+        return result
     def getMessage(self):
         global message
         return message
\ No newline at end of file
